"""Constants used throughout the Airia SDK."""

# Default API endpoints
DEFAULT_BASE_URL = "https://api.airia.ai/"
DEFAULT_OPENAI_GATEWAY_URL = "https://gateway.airia.ai/openai/v1"
DEFAULT_ANTHROPIC_GATEWAY_URL = "https://gateway.airia.ai/anthropic"

# Default timeouts
DEFAULT_TIMEOUT = 30.0